@@ -36,12 +36,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #endif //HAVE_PCIUTILS
 #include <QRegExp>
 #include <QFile>
-#include <QHeaderView>
 
 #include <KLocalizedString>
 #include <kiconloader.h>
-#include <kglobalsettings.h>
-#include <kdebug.h>
+#include <QFontDatabase>
 
 #define INFO_IRQ "/proc/interrupts"
 #define INFO_DMA "/proc/dma"
@@ -94,7 +92,7 @@ bool GetInfo_ReadfromFile(QTreeWidget* tree, const char *FileName, const QChar&
 }
 
 bool GetInfo_IRQ(QTreeWidget* tree) {
-	tree->setFont(KGlobalSettings::fixedFont());
+	tree->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
 	tree->setHeaderHidden(true);
 	
 	return GetInfo_ReadfromFile(tree, INFO_IRQ, 0);
@@ -164,20 +162,6 @@ bool GetInfo_SCSI(QTreeWidget* tree) {
 	return GetInfo_ReadfromFile(tree, INFO_SCSI, 0);
 }
 
-static void cleanPassword(QString & str) {
-	int index = 0;
-	QString passwd("password=");
-
-	while (index >= 0) {
-		index = str.indexOf(passwd, index, Qt::CaseInsensitive);
-		if (index >= 0) {
-			index += passwd.length();
-			while (index < (int) str.length() && str[index] != ' ' && str[index] != ',')
-				str[index++] = '*';
-		}
-	}
-}
-
 bool GetInfo_XServer_and_Video(QTreeWidget* tree) {
 	return GetInfo_XServer_Generic(tree);
 }
